@@ -14,7 +14,7 @@
 #define PETSC_DEPRECATED_MACRO_BASE_(why) _Pragma(#why)
 #define PETSC_DEPRECATED_OBJECT_BASE(string_literal_why) __attribute__((deprecated(string_literal_why)))
 #define PETSC_DEPRECATED_TYPEDEF_BASE(string_literal_why) __attribute__((deprecated(string_literal_why)))
-#define PETSC_DIR "/c/M/B/src/build-CLANGARM64/petsc-3.21.5"
+#define PETSC_DIR "/c/M/B/src/build-CLANGARM64/petsc-3.22.0"
 #define PETSC_DIR_SEPARATOR '/'
 #define PETSC_FUNCTION_NAME_C __func__
 #define PETSC_HAVE_ACCESS 1
@@ -53,6 +53,8 @@
 #define PETSC_HAVE_MEMMOVE 1
 #define PETSC_HAVE_MKSTEMP 1
 #define PETSC_HAVE_MPIUNI 1
+#define PETSC_HAVE_MPI_COUNT 1
+#define PETSC_HAVE_MPI_LARGE_COUNT 1
 #define PETSC_HAVE_MPI_REDUCE_LOCAL 1
 #define PETSC_HAVE_OPENBLAS 1
 #define PETSC_HAVE_OPENBLAS_SET_NUM_THREADS 1
@@ -99,7 +101,7 @@
 #define PETSC_IS_COLORING_VALUE_TYPE short
 #define PETSC_IS_COLORING_VALUE_TYPE_F integer2
 #define PETSC_LEVEL1_DCACHE_LINESIZE 32
-#define PETSC_LIB_DIR "/c/M/B/src/build-CLANGARM64/petsc-3.21.5/sso/lib"
+#define PETSC_LIB_DIR "/c/M/B/src/build-CLANGARM64/petsc-3.22.0/sso/lib"
 #define PETSC_MAX_PATH_LEN 260
 #define PETSC_MEMALIGN 16
 #define PETSC_MISSING_GETLINE 1
